@@ -806,12 +806,22 @@ EOF
     if ($self->versionmode eq 'ignore' and $self->config->download_version) {
         uscan_verbose 'Ignore --download_version for component with "ignore"';
     } elsif ($self->config->download_version) {
-        $self->shared->{download_version} = $self->config->download_version;
+        my $mangled_downloadversion = $self->config->download_version;
+        if (
+            mangle(
+                $watchfile,        \$self->line,
+                'uversionmangle:', \@{ $self->uversionmangle },
+                \$mangled_downloadversion
+            )
+        ) {
+            return $self->status(1);
+        }
+        $self->shared->{download_version} = $mangled_downloadversion;
         $self->shared->{download}         = 2
           if $self->shared->{download} == 1;    # Change default 1 -> 2
         $self->badversion(1);
         uscan_verbose "Download the --download-version specified version: "
-          . "$self->{shared}->{download_version}";
+          . "(uversionmangled): $self->{shared}->{download_version}";
     } elsif ($self->config->download_debversion) {
         $self->shared->{download_version} = $mangled_lastversion;
         $self->shared->{download}         = 2
