@@ -92,6 +92,10 @@ signed using gnupg. Currently this is only supported by git, hg, and bzr.
 If this option is set, then tags that debcommit creates will be signed
 using gnupg. Currently this is only supported by git.
 
+=item B<--signoff>, B<--no-signoff>
+
+If this option is set, add a "Signed-off-by:" line to the commit message.
+
 =item B<--changelog-info>
 
 If this option is set, the commit author and date will be determined from
@@ -126,6 +130,11 @@ line parameter being used. The default is I<no>.
 If this is set to I<yes>, then it is the same as the B<--sign-commit>
 command line parameter being used. The default is I<no>.
 
+=item B<DEBCOMMIT_SIGNOFF>
+
+If this is set to I<yes>, then it is the same as the B<--signoff> command
+line parameter being used. The default is I<no>.
+
 =item B<DEBCOMMIT_RELEASE_USE_CHANGELOG>
 
 If this is set to I<yes>, then it is the same as the B<--release-use-changelog>
@@ -219,6 +228,8 @@ Options:
    --no-sign-commit    Do not sign the commit (default)
    --sign-tags         Enable signing of tags (git only)
    --no-sign-tags      Do not sign tags (default)
+   --signoff           Add a Signed-off-by line to the commit message
+   --no-signoff        Do not add a Signed-off-by line to the commit message (default)
    --changelog-info    Use author and date information from the changelog
                        for the commit (git, hg, and bzr)
    -h --help           This message
@@ -255,6 +266,7 @@ my $all                   = 0;
 my $stripmessage          = 1;
 my $signcommit            = 0;
 my $signtags              = 0;
+my $signoff               = 0;
 my $changelog;
 my $changelog_info = 0;
 my $keyid;
@@ -273,6 +285,7 @@ if (@ARGV and $ARGV[0] =~ /^--no-?conf$/) {
         'DEBCOMMIT_STRIP_MESSAGE'         => 'yes',
         'DEBCOMMIT_SIGN_COMMITS'          => 'no',
         'DEBCOMMIT_SIGN_TAGS'             => 'no',
+        'DEBCOMMIT_SIGNOFF'               => 'no',
         'DEBCOMMIT_RELEASE_USE_CHANGELOG' => 'no',
         'DEBSIGN_KEYID'                   => '',
     );
@@ -311,6 +324,7 @@ if (@ARGV and $ARGV[0] =~ /^--no-?conf$/) {
     $stripmessage = $config_vars{'DEBCOMMIT_STRIP_MESSAGE'} eq 'no' ? 0 : 1;
     $signcommit   = $config_vars{'DEBCOMMIT_SIGN_COMMITS'} eq 'no'  ? 0 : 1;
     $signtags     = $config_vars{'DEBCOMMIT_SIGN_TAGS'} eq 'no'     ? 0 : 1;
+    $signoff      = $config_vars{'DEBCOMMIT_SIGNOFF'} eq 'no'       ? 0 : 1;
     $release_use_changelog
       = $config_vars{'DEBCOMMIT_RELEASE_USE_CHANGELOG'} eq 'no' ? 0 : 1;
     if (exists $config_vars{'DEBSIGN_KEYID'}
@@ -343,6 +357,7 @@ if (
         "s|strip-message!"         => \$stripmessage,
         "sign-commit!"             => \$signcommit,
         "sign-tags!"               => \$signtags,
+        "signoff!"                 => \$signoff,
         "changelog-info!"          => \$changelog_info,
         "R|release-use-changelog!" => \$release_use_changelog,
         "h|help"                   => sub { usage();   exit 0; },
@@ -587,6 +602,9 @@ sub commit {
                 $sign .= "=$keyid" if $keyid;
                 push(@extra_args, $sign);
             }
+            if ($signoff) {
+                push(@extra_args, '--signoff');
+            }
             $action_rc = action($prog, "commit", "-m", $message, @extra_args,
                 @files_to_commit);
         }
