@@ -720,7 +720,9 @@ if ($type eq 'deb') {
             push @opts, '--skip-patches';
         }
         my $diri = ${"dir$i"};
-        if ($origs[1] eq $origs[2] and $dscformats[$i] eq '3.0 (quilt)') {
+        if (    $origs[1] eq $origs[2]
+            and $dscformats[$i] eq '3.0 (quilt)'
+            and !$apply_patches) {
             eval {
                 my $source = $origs[$i];
                 $source =~ s/\.orig\.tar\.$compression_re//;
