@@ -490,22 +490,17 @@ def download_packages(
 
     os.makedirs(tmpdirname + "/cache")
 
+    apt_env = {"APT_CONFIG": tmpdirname + "/apt.conf"}
     if not nocache:
         port, teardown = setupcache(cache, port)
+        apt_env["http_proxy"] = f"http://127.0.0.1:{port}"
         atexit.register(teardown)
-    else:
-        port = None
 
     with open(tmpdirname + "/etc/apt/sources.list", "w", encoding="utf8") as f:
         for source in sources:
             f.write(source.deb_line("snapshot.debian.org"))
-    subprocess.check_call(
-        ["apt-get", "update", "--error-on=any"],
-        env={
-            "APT_CONFIG": tmpdirname + "/apt.conf",
-            "http_proxy": f"http://127.0.0.1:{port}",
-        },
-    )
+    subprocess.check_call(["apt-get", "update", "--error-on=any"], env=apt_env)
+
     deb_files = []
     cache = pathlib.Path(tmpdirname, "cache")
     for i, (name, arch, version) in enumerate(pkgs):
@@ -515,10 +510,7 @@ def download_packages(
             subprocess.check_call(
                 ["apt-get", "download", "--yes", pkg],
                 cwd=tmpdir2,
-                env={
-                    "APT_CONFIG": tmpdirname + "/apt.conf",
-                    "http_proxy": f"http://127.0.0.1:{port}",
-                },
+                env=apt_env,
             )
             debs = os.listdir(tmpdir2)
             assert len(debs) == 1
