@@ -24,6 +24,7 @@ use Dpkg::Control::FieldsCore;
 use Dpkg::Index;
 use Dpkg::Deps;
 use Dpkg::Source::Package;
+use Dpkg::Version;
 use File::Temp qw(tempfile tempdir);
 use File::Path qw(make_path);
 use File::HomeDir;
@@ -376,6 +377,7 @@ foreach my $line (split /\n/, $cdata->{"Environment"}) {
 
 # gather all installed build-depends and figure out the version of base-files
 my $base_files_version;
+my $dpkg_version;
 my @inst_build_deps = ();
 $inst_build_deps
   = deps_parse($inst_build_deps, reduce_arch => 0, build_dep => 0);
@@ -405,6 +407,11 @@ foreach my $pkg ($inst_build_deps->get_deps()) {
             die "more than one base-files\n";
         }
         $base_files_version = $pkg->{version};
+    } elsif ($pkg->{package} eq "dpkg") {
+        if (defined($dpkg_version)) {
+            die "more than one dpkg\n";
+        }
+        $dpkg_version = $pkg->{version};
     }
     push @inst_build_deps,
       {
@@ -622,6 +629,7 @@ if ($builder eq "none") {
     # dependencies installed, so make running apt-get and apt-cache a no-op
     print $fh "\$apt_get = '/bin/true';\n";
     print $fh "\$apt_cache = '/bin/true';\n";
+    print $fh "\$build_as_root_when_needed = 1;\n";
     close $fh;
     my @cmd = (
         'env', "--chdir=$outdir", @environment, "SBUILD_CONFIG=$sbuildrc",
@@ -661,10 +669,13 @@ if ($builder eq "none") {
     # so it is not included in the recreated chroot.
     # Since most packages build without issues,
     # this simply forces dpkg-buildpackage to run without fakeroot.
-    push @cmd,
-        "--starting-build-commands="
-      . 'grep -iq "^Rules-Requires-Root:" "%p/debian/control" || '
-      . 'sed -i "1iRules-Requires-Root: no" "%p/debian/control"';
+    # the default was switched in 1.22.13 so no longer needed afterwards.
+    if ($dpkg_version < Dpkg::Version->new("1.22.13")) {
+        push @cmd,
+            "--starting-build-commands="
+          . 'grep -iq "^Rules-Requires-Root:" "%p/debian/control" || '
+          . 'sed -i "1iRules-Requires-Root: no" "%p/debian/control"';
+    }
     # without --verbose, the log will be suppressed by default if sbuild is
     # not run on an interactive tty, so we make sure the behaviour is always
     # the same independent how debrebuild is run
