@@ -172,6 +172,8 @@ signfile() {
 
     $signcommand --no-auto-check-trustdb \
 	--local-user "$signas" --clearsign \
+	--openpgp \
+	--personal-digest-preferences 'SHA512 SHA384 SHA256 SHA224' \
 	--list-options no-show-policy-urls \
 	--armor --textmode --output "$ASCII_SIGNED_FILE"\
 	"$UNSIGNED_FILE" || \
